==> humhub-1.8.0-beta.1.tar.gz: humhub-1.8.0-beta.1/protected/humhub/modules/user/messages/de/account.php <==
<?php
return array (
  '<strong>Account</strong> settings' => '<strong>Benutzerkonto</strong>',
  '<strong>Confirm</strong></strong> your new email address' => '<strong>Bestätige</strong> deine neue E-Mail Adresse',
  '<strong>Permissions</strong>' => '<strong>Berechtigungen</strong>',
  '<strong>User</strong> modules' => '<strong>Benutzer</strong>-Module',
  '<strong>User</strong> settings' => '<strong>Benutzer</strong>-Einstellungen',
  '<strong>Your</strong> profile' => '<strong>Dein</strong> Profil',
  'All your personal data will be irrevocably deleted.' => 'Alle Deine persönlichen Daten werden unwiderruflich gelöscht.',
  'Are you really sure? *ALL* module data for your profile will be deleted!' => 'Bist du dir wirklich sicher? *ALLE* Moduldaten für dein Profil werden gelöscht!',
  'Are you sure that you want to delete your account?' => 'Bist du sicher, dass du Dein Benutzerkonto löschen möchtest?',
  'Changing the username can make some links unusable, for example old links to the profile.' => 'Wenn der Benutzername geändert wird, können ältere Links unbrauchbar werden (z. B. Links zum Profil)',
  'Configure' => 'Konfigurieren',
  'Confirm' => 'Bestätigen',
  'Current password' => 'Aktuelles Passwort',
  'Delete account' => 'Benutzerkonto löschen',
  'Disable' => 'Deaktivieren',
  'Do you really want to delete your icon image?' => 'Möchtest du dein Icon-Bild wirklich löschen?',
  'Do you really want to delete your logo image?' => 'Willst du das Logo wirklich entfernen?',
  'E-Mail' => 'E-Mail',
  'E-Mail change' => 'E-Mail-Adresse ändern',
  'Enable' => 'Aktivieren',
  'Enhance your profile with modules.' => 'Erweitere dein Profil durch Module.',
  'Enter your password to continue' => 'Gib dein Passwort ein, um fortzufahren',
  'Hello' => 'Hallo',
  'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Hier kannst du deine allgemeinen Profildaten bearbeiten, die auf der Übersichtsseite deines Profils sichtbar sind.',
  'Hide introduction tour panel on dashboard' => 'Einführungstour in der Übersicht ausblenden',
  'Invalid link! Please make sure that you entered the entire url.' => 'Ungültiger Link! Bitte vergewissere dich, dass die vollständige URL eingegeben wurde.',
  'Language' => 'Sprache',
  'Modules' => 'Module',
  'New E-Mail address' => 'Neue E-Mail-Adresse',
  'New User name' => 'Neuer Benutzername',
  'Not registered users' => 'Keine registrierten Benutzer',
  'Notifications' => 'Benachrichtungen',
  'Other users' => 'Andere Benutzer',
  'Password Recovery' => 'Passwort-Wiederherstellung',
  'Permissions' => 'Berechtigungen',
  'Profile' => 'Profil',
  'Profile visibility' => 'Profilsichtbarkeit',
  'Registered users only' => 'Nur registrierte Benutzer',
  'Save' => 'Speichern',
  'Save profile' => 'Profil speichern',
  'Settings' => 'Einstellungen',
  'Tags' => 'Tags',
  'The entered e-mail address is already in use by another user.' => 'Die eingetragene E-Mail-Adresse wird bereits von einem anderen Benutzer verwendet.',
  'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Diese Menü ermöglicht es dir festzulegen, welche Berechtigungen du Gästen deines Profil gewähren willst. Die Einstellungsmöglichkeiten setzt jeder Benutzer individuell und ausschließlich für dein eignes Profil.',
  'TimeZone' => 'Zeitzone',
  'Username has been changed' => 'Benutzername wurde geändert',
  'Users' => 'Benutzer',
  'Visible for all (also unregistered users)' => 'Sichtbar für alle (auch unregistrierte Benutzer)',
  'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Wir haben soeben eine Bestätigungs-E-Mail an deine neue Adresse geschickt.<br />Bitte folge den darin enthaltenen Anweisungen.',
  'You are currently the owner of following spaces:' => 'Du bist derzeit Besitzer von folgenden Spaces:',
  'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Du hast die Änderung deiner E-Mail-Adresse beantragt.<br />Deine neue E-Mail-Adresse ist {newemail}.<br /><br />Um die neue E-Mail-Adresse zu bestätigen, klicke bitte auf den Button unten.',
  'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Dein Benutzername wurde erfolgreich geändert.<br />Dein neuer Benutzername ist {newUsername}.',
  'You must transfer ownership or delete these spaces before you can delete your account.' => 'Bevor das Benutzerkonto gelöscht werden kann, musst du den Besitz über diese Space auf einen anderen Benutzer übertragen.',
  'Your account cannot be deleted!' => 'Dein Benutzerkonto kann nicht gelöscht werden!',
  'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Deine aktuelle E-Mail-Adresse ist <b>{email}</b>. Du kannst sie hier ändern.',
  'Your current password can be changed here.' => 'Dein aktuelles Passwort kann hier geändert werden.',
  'Your current username is <b>{username}</b>. You can change your current username here.' => 'Dein aktueller Benutzername ist <b>{username}</b>. Du kannst deinen aktuellen Benutzernamen hier ändern.',
  'Your e-mail address has been successfully changed to {email}.' => 'Deine E-Mail-Adresse wurde erfolgreich in {email} geändert.',
  'Your friends' => 'Deine Freunde',
  'Your password has been successfully changed!' => 'Dein Passwort wurde erfolgreich geändert!',
  'Your username has been changed' => 'Dein Benutzername wurde geändert',
  'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Dein Benutzername wurde erfolgreich geändert.<br />Wir haben dir gerade eine E-Mail mit neuer Information gesandt.',
  '{attribute} "{value}" was not found!' => '{attribute} "{value}" nicht gefunden!',
);

==> humhub-1.15.0-beta.1.tar.gz: humhub-1.15.0-beta.1/protected/humhub/modules/user/messages/de/account.php <==
<?php
return array (
  '<strong>Account</strong> Settings' => '<strong>Kontoeinstellungen</strong>',
  '<strong>Confirm</strong></strong> your new email address' => '<strong>Bestätige</strong> deine neue E-Mail Adresse',
  '<strong>Permissions</strong>' => '<strong>Berechtigungen</strong>',
  '<strong>Your</strong> Account' => '',
  '<strong>Your</strong> profile' => '<strong>Dein</strong> Profil',
  'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Füge deinem Profil Schlagwörter (Tags) hinzu, die dich beschreiben und zeige anderen Nutzern deine Fähigkeiten und Interessen. Die Tags werden in deinem Profil und im Benutzerverzeichnis angezeigt.',
  'All your personal data will be irrevocably deleted.' => 'Alle Deine persönlichen Daten werden unwiderruflich gelöscht.',
  'Are you sure that you want to delete your account?' => 'Bist du sicher, dass du Dein Benutzerkonto löschen möchtest?',
  'Blocked users' => 'Blockierte Benutzer',
  'Changing the username can make some links unusable, for example old links to the profile.' => 'Wenn der Benutzername geändert wird, können ältere Links unbrauchbar werden (z. B. Links zum Profil)',
  'Confirm' => 'Bestätigen',
  'Current password' => 'Aktuelles Passwort',
  'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Lege grundlegende Einstellungen deines Profils fest. Du kannst beschreibende Tags hinzufügen, die angezeigte Sprache und Zeitzone wählen und unfreundliche Benutzer blockieren.',
  'Delete account' => 'Benutzerkonto löschen',
  'Do you really want to delete your icon image?' => 'Möchtest du dein Icon-Bild wirklich löschen?',
  'Do you really want to delete your logo image?' => 'Willst du das Logo wirklich entfernen?',
  'E-Mail' => 'E-Mail',
  'E-Mail change' => 'E-Mail-Adresse ändern',
  'Enter your password to continue' => 'Gib dein Passwort ein, um fortzufahren',
  'General' => 'Allgemein',
  'Hello' => 'Hallo',
  'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Hier kannst du deine allgemeinen Profildaten bearbeiten, die auf der Übersichtsseite deines Profils sichtbar sind.',
  'Hide introduction tour panel on dashboard' => 'Einführungstour in der Übersicht ausblenden',
  'Hide my online status' => '',
  'Invalid link! Please make sure that you entered the entire url.' => 'Ungültiger Link! Bitte vergewissere dich, dass die vollständige URL eingegeben wurde.',
  'Language' => 'Sprache',
  'Markdown Editor Mode' => '',
  'Modules' => 'Module',
  'New E-Mail address' => 'Neue E-Mail-Adresse',
  'New User name' => 'Neuer Benutzername',
  'Not registered users' => 'Keine registrierten Benutzer',
  'Notifications' => 'Benachrichtigungen',
  'Other users' => 'Andere Benutzer',
  'Password Recovery' => 'Passwort-Wiederherstellung',
  'Permissions' => 'Berechtigungen',
  'Plain' => '',
  'Profile' => 'Profil',
  'Profile Tags' => 'Profil-Tags (Schlagwörter)',
  'Profile visibility' => 'Profilsichtbarkeit',
  'Registered users only' => 'Nur registrierte Benutzer',
  'Rich Text' => '',
  'Save' => 'Speichern',
  'Save profile' => 'Profil speichern',
  'The entered e-mail address is already in use by another user.' => 'Die eingetragene E-Mail-Adresse wird bereits von einem anderen Benutzer verwendet.',
  'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Diese Menü ermöglicht es dir festzulegen, welche Berechtigungen du Gästen deines Profil gewähren willst. Die Einstellungsmöglichkeiten setzt jeder Benutzer individuell und ausschließlich für dein eignes Profil.',
  'TimeZone' => 'Zeitzone',
  'Username has been changed' => 'Benutzername wurde geändert',
  'Users' => 'Benutzer',
  'Visible for all (also unregistered users)' => 'Sichtbar für alle (auch unregistrierte Benutzer)',
  'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Wir haben soeben eine Bestätigungs-E-Mail an deine neue Adresse geschickt.<br />Bitte folge den darin enthaltenen Anweisungen.',
  'You are currently the owner of following spaces:' => 'Du bist derzeit Besitzer von folgenden Spaces:',
  'You cannot use this username.' => 'Du kannst diesen Benutzernamen nicht verwenden.',
  'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Du hast die Änderung deiner E-Mail-Adresse beantragt.<br />Deine neue E-Mail-Adresse ist {newemail}.<br /><br />Um die neue E-Mail-Adresse zu bestätigen, klicke bitte auf den Button unten.',
  'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Dein Benutzername wurde erfolgreich geändert.<br />Dein neuer Benutzername ist {newUsername}.',
  'You must transfer ownership or delete these spaces before you can delete your account.' => 'Bevor das Benutzerkonto gelöscht werden kann, musst du den Besitz über diese Space auf einen anderen Benutzer übertragen.',
  'Your account cannot be deleted!' => 'Dein Benutzerkonto kann nicht gelöscht werden!',
  'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Deine aktuelle E-Mail-Adresse ist <b>{email}</b>. Du kannst sie hier ändern.',
  'Your current password can be changed here.' => 'Dein aktuelles Passwort kann hier geändert werden.',
  'Your current username is <b>{username}</b>. You can change your current username here.' => 'Dein aktueller Benutzername ist <b>{username}</b>. Du kannst deinen aktuellen Benutzernamen hier ändern.',
  'Your e-mail address has been successfully changed to {email}.' => 'Deine E-Mail-Adresse wurde erfolgreich in {email} geändert.',
  'Your friends' => 'Deine Freunde',
  'Your password has been successfully changed!' => 'Dein Passwort wurde erfolgreich geändert!',
  'Your username has been changed' => 'Dein Benutzername wurde geändert',
  'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Dein Benutzername wurde erfolgreich geändert.<br />Wir haben dir gerade eine E-Mail mit neuer Information gesandt.',
);
